/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import org.openide.filesystems.FileObject;
import it.tidalwave.actor.MessageSupport;
import it.tidalwave.actor.annotation.Message;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import static lombok.AccessLevel.*;

/***********************************************************************************************************************
 * 
 * @stereotype Message
 * 
 * A message which notifies that an error has been discovered on a file.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Message @Immutable
@RequiredArgsConstructor(access=PRIVATE) @EqualsAndHashCode @ToString(callSuper=false)
public class FileDamageDetectedMessage extends MessageSupport
  {
    @Nonnull @Getter
    private final FileObject fileObject;  
    
    @Nonnull @Getter
    private final Throwable cause;
    
    @Nonnull
    public static FileDamageDetectedMessage forFile (final @Nonnull FileObject fileObject)
      {
        return new FileDamageDetectedMessage(fileObject, new Exception());  
      }
    
    @Nonnull
    public FileDamageDetectedMessage withCause (final @Nonnull Throwable cause)
      {
        return new FileDamageDetectedMessage(fileObject, cause);  
      }
  }
