/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.io.File;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import it.tidalwave.actor.MessageSupport;
import it.tidalwave.actor.annotation.Message;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import static lombok.AccessLevel.PRIVATE;

/***********************************************************************************************************************
 * 
 * @stereotype Message
 * 
 * A message for requesting the scan of a folder.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Message
@Immutable @RequiredArgsConstructor(access=PRIVATE) @EqualsAndHashCode @ToString(callSuper=false)
public class FileScanRequestMessage extends MessageSupport
  {
    public static interface Filter 
      {
        public static final Filter ANY = new Filter() 
          {
            @Override
            public boolean accepts (final @Nonnull FileObject fileObject) 
              {
                return true;
              }
          };
        
        public boolean accepts (@Nonnull FileObject fileObject);  
      }
      
    @Nonnull @Getter
    private final FileObject folder;  
    
    @Nonnull @Getter
    private final Filter filter;  
    
    @Nonnull
    public static FileScanRequestMessage forPath (final @Nonnull String path)
      {
        return forFolder(new File(path)); 
      }
    
    @Nonnull
    public static FileScanRequestMessage forFolder (final @Nonnull File file)
      {
        return forFolder(FileUtil.toFileObject(file));
      }    
    
    @Nonnull
    public static FileScanRequestMessage forFolder (final @Nonnull FileObject fileObject)
      {
        return new FileScanRequestMessage(fileObject, Filter.ANY);
      }    
    
    @Nonnull
    public FileScanRequestMessage withFilter (final @Nonnull Filter filter)
      {  
        return new FileScanRequestMessage(folder, filter);  
      }
  }
