/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker.filter;

import javax.annotation.Nonnull;
import java.util.Arrays;
import java.util.List;
import it.tidalwave.integritychecker.FileScanRequestMessage;
import org.openide.filesystems.FileObject;
import lombok.RequiredArgsConstructor;
import static lombok.AccessLevel.PRIVATE;

/***********************************************************************************************************************
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@RequiredArgsConstructor(access=PRIVATE)
public class FileExtensionFilter implements FileScanRequestMessage.Filter
  {
    @Nonnull
    private final List<String> extensions;
    
    public static FileExtensionFilter withExtensions (final @Nonnull String ... args)
      {
        return new FileExtensionFilter(Arrays.asList(args));
      }

    @Override
    public boolean accepts (final @Nonnull FileObject fileObject) 
      {
//          System.err.println(" EXT " + fileObject.getExt() + " > " + extensions);
        return fileObject.isFolder() || extensions.contains(fileObject.getExt());
      }
  }
